@@ -1,7 +1,9 @@
+## no critic: ControlStructures::ProhibitMutatingListFunctions
+
 package Software::Catalog::SW::zcoin::qt;
 
-our $DATE = '2018-10-18'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-01-14'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,6 +50,59 @@ sub canon2native_arch_map {
     },
 }
 
+sub get_available_versions {
+    my ($self, %args) = @_;
+
+    my $res = extract_from_url(
+        url => "https://github.com/zcoinofficial/zcoin/releases",
+        re  => qr!/zcoinofficial/zcoin/tree/([^"/]+)!,
+        all => 1,
+    );
+    return $res unless $res->[0] == 200;
+    # sort versions from earliest
+    $res->[2] = [ sort { $self->cmp_version($a, $b) }
+                      map { s/\Av//; $_ }
+                      @{$res->[2]}];
+    $res;
+}
+
+sub get_release_note {
+    require Mojo::DOM;
+
+    my ($self, %args) = @_;
+    my $format = $args{format} // 'text';
+
+    my $version = $args{version} // do {
+        my $res = $self->get_latest_version(%args);
+        return $res unless $res->[0] == 200;
+        $res->[2];
+    };
+
+    $version =~ s/\Av//;
+
+    my $url = "https://github.com/zcoinofficial/zcoin/releases/tag/v$version";
+    my $res = extract_from_url(
+      url => $url,
+      code => sub {
+          my %cargs = @_;
+          my $dom = Mojo::DOM->new($cargs{content});
+          my $html = $dom->at(".markdown-body")->content;
+
+          if ($html) {
+              if ($format eq 'html') {
+                  return [200, "OK", $html];
+              } else {
+                  require HTML::FormatText::Any;
+                  return [200, "OK",
+                          HTML::FormatText::Any::html2text(html => $html)->[2]];
+              }
+          } else {
+              return [543, "Cannot scrape release note text from $url"];
+          }
+      },
+  );
+}
+
 # version
 # arch
 sub get_download_url {
@@ -106,7 +161,7 @@ Software::Catalog::SW::zcoin::qt - Zcoin desktop GUI client
 
 =head1 VERSION
 
-This document describes version 0.005 of Software::Catalog::SW::zcoin::qt (from Perl distribution Software-Catalog-SW-zcoin-qt), released on 2018-10-18.
+This document describes version 0.006 of Software::Catalog::SW::zcoin::qt (from Perl distribution Software-Catalog-SW-zcoin-qt), released on 2019-01-14.
 
 =for Pod::Coverage ^(.+)$
 
@@ -132,7 +187,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
